@@ -400,7 +400,7 @@ def _start(client, bot):
 							users = await react.users().flatten()
 							for user in users:
 								if user.id!=client.user.id:
-									userstr+=str(user.id)+","
+									userstr+=str(user.id)+bot._separator
 					userstr=userstr[:-1]
 					line=line.replace("$getReactions"+bot._style[0]+line.split("$getReactions"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],userstr)
 				except Exception as e:
@@ -492,7 +492,7 @@ def _start(client, bot):
 			else:
 				nowloop=line
 				try:
-					r=line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0].replace(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1],line[len(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]+bot._separator+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]+bot._separator):])
+					r=line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0].replace(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1],line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2])
 					line=line.replace("$replaceText"+bot._style[0]+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(r))
 				except:
 					line=line.replace("$replaceText"+bot._style[0]+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none") 
